Principal components analysis
=============================

.. automodule:: anhima.pca
.. autofunction:: pca
.. autofunction:: plot_coords
.. autofunction:: plot_variance_explained
.. autofunction:: plot_loadings
